Garfield.modules.GNNModelVAE
============================

.. currentmodule:: Garfield.modules

.. autoclass:: GNNModelVAE

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
   
      ~GNNModelVAE.__init__
      ~GNNModelVAE.add_module
      ~GNNModelVAE.apply
      ~GNNModelVAE.bfloat16
      ~GNNModelVAE.buffers
      ~GNNModelVAE.children
      ~GNNModelVAE.compile
      ~GNNModelVAE.cpu
      ~GNNModelVAE.cuda
      ~GNNModelVAE.decode
      ~GNNModelVAE.double
      ~GNNModelVAE.encode
      ~GNNModelVAE.eval
      ~GNNModelVAE.extra_repr
      ~GNNModelVAE.float
      ~GNNModelVAE.forward
      ~GNNModelVAE.get_buffer
      ~GNNModelVAE.get_extra_state
      ~GNNModelVAE.get_latent_representation
      ~GNNModelVAE.get_parameter
      ~GNNModelVAE.get_submodule
      ~GNNModelVAE.half
      ~GNNModelVAE.ipu
      ~GNNModelVAE.load_state_dict
      ~GNNModelVAE.loss
      ~GNNModelVAE.modules
      ~GNNModelVAE.named_buffers
      ~GNNModelVAE.named_children
      ~GNNModelVAE.named_modules
      ~GNNModelVAE.named_parameters
      ~GNNModelVAE.parameters
      ~GNNModelVAE.recon_loss
      ~GNNModelVAE.register_backward_hook
      ~GNNModelVAE.register_buffer
      ~GNNModelVAE.register_forward_hook
      ~GNNModelVAE.register_forward_pre_hook
      ~GNNModelVAE.register_full_backward_hook
      ~GNNModelVAE.register_full_backward_pre_hook
      ~GNNModelVAE.register_load_state_dict_post_hook
      ~GNNModelVAE.register_module
      ~GNNModelVAE.register_parameter
      ~GNNModelVAE.register_state_dict_pre_hook
      ~GNNModelVAE.reparameterize
      ~GNNModelVAE.requires_grad_
      ~GNNModelVAE.reset_parameters
      ~GNNModelVAE.set_extra_state
      ~GNNModelVAE.share_memory
      ~GNNModelVAE.state_dict
      ~GNNModelVAE.test
      ~GNNModelVAE.to
      ~GNNModelVAE.to_empty
      ~GNNModelVAE.train
      ~GNNModelVAE.type
      ~GNNModelVAE.xpu
      ~GNNModelVAE.zero_grad
   
   

   
   
   .. rubric:: Attributes

   .. autosummary::
   
      ~GNNModelVAE.T_destination
      ~GNNModelVAE.call_super_init
      ~GNNModelVAE.dump_patches
      ~GNNModelVAE.training
   
   